==> ogre-13.0.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_input_8h.js <==
var _ogre_input_8h =
[
    [ "Keycode", "_ogre_input_8h.html#gab14133fb878c499e285cdc324b9bac9b", null ],
    [ "ButtonType", "_ogre_input_8h.html#ga0e65e21efd2d9ea8a53d576eb95f51cc", [
      [ "BUTTON_LEFT", "_ogre_input_8h.html#gga0e65e21efd2d9ea8a53d576eb95f51ccab7d0a64cc61f56c6ef02d5ebc2dd2dc6", null ],
      [ "BUTTON_MIDDLE", "_ogre_input_8h.html#gga0e65e21efd2d9ea8a53d576eb95f51cca8f8cd4b0e1f66027b25e4d37eb6c9922", null ],
      [ "BUTTON_RIGHT", "_ogre_input_8h.html#gga0e65e21efd2d9ea8a53d576eb95f51ccaff4ae5d88e4634c2ed3691ae0d87adcf", null ]
    ] ],
    [ "EventType", "_ogre_input_8h.html#gafba156da7d846753caa2c0be29f6da0d", [
      [ "KEYDOWN", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da7b68f60dabd93e60586647bfac665c90", null ],
      [ "KEYUP", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da188b36c72a17191940791014812de740", null ],
      [ "MOUSEBUTTONDOWN", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da2077dadd76ee5db9c8e3f8a383a5957e", null ],
      [ "MOUSEBUTTONUP", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da30af493b2208347cd602b9611d72c0a9", null ],
      [ "MOUSEWHEEL", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da1c3b27a0c22a5b0716c8d07835faabf3", null ],
      [ "MOUSEMOTION", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da9c4c9f4faaffc09c64da3039b7a2312a", null ],
      [ "FINGERDOWN", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da573edcf30dd284359cc0f74bfb91f67f", null ],
      [ "FINGERUP", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0dafc4fa4cb82cf64a48c6cd2209154d649", null ],
      [ "FINGERMOTION", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da1affffec072d6d4b6f8503e532a857e2", null ],
      [ "TEXTINPUT", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0dae1c4a9cee7e1a452d3455b63f7bd2984", null ],
      [ "CONTROLLERAXISMOTION", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da02ad0ee43faa3821dafd230ddb885ccb", null ],
      [ "CONTROLLERBUTTONDOWN", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da0eb561d30eb04f7403af3fd1204870b0", null ],
      [ "CONTROLLERBUTTONUP", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da2d97ea0d3b7e53fd317627c2a8117f91", null ]
    ] ]
];

==> ogre-14.2.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_input_8h.js <==
var _ogre_input_8h =
[
    [ "Keycode", "_ogre_input_8h.html#gab14133fb878c499e285cdc324b9bac9b", null ],
    [ "ButtonType", "_ogre_input_8h.html#ga0e65e21efd2d9ea8a53d576eb95f51cc", [
      [ "BUTTON_LEFT", "_ogre_input_8h.html#gga0e65e21efd2d9ea8a53d576eb95f51ccab7d0a64cc61f56c6ef02d5ebc2dd2dc6", null ],
      [ "BUTTON_MIDDLE", "_ogre_input_8h.html#gga0e65e21efd2d9ea8a53d576eb95f51cca8f8cd4b0e1f66027b25e4d37eb6c9922", null ],
      [ "BUTTON_RIGHT", "_ogre_input_8h.html#gga0e65e21efd2d9ea8a53d576eb95f51ccaff4ae5d88e4634c2ed3691ae0d87adcf", null ]
    ] ],
    [ "EventType", "_ogre_input_8h.html#gafba156da7d846753caa2c0be29f6da0d", [
      [ "KEYDOWN", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da7b68f60dabd93e60586647bfac665c90", null ],
      [ "KEYUP", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da188b36c72a17191940791014812de740", null ],
      [ "MOUSEBUTTONDOWN", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da2077dadd76ee5db9c8e3f8a383a5957e", null ],
      [ "MOUSEBUTTONUP", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da30af493b2208347cd602b9611d72c0a9", null ],
      [ "MOUSEWHEEL", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da1c3b27a0c22a5b0716c8d07835faabf3", null ],
      [ "MOUSEMOTION", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da9c4c9f4faaffc09c64da3039b7a2312a", null ],
      [ "FINGERDOWN", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da573edcf30dd284359cc0f74bfb91f67f", null ],
      [ "FINGERUP", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0dafc4fa4cb82cf64a48c6cd2209154d649", null ],
      [ "FINGERMOTION", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da1affffec072d6d4b6f8503e532a857e2", null ],
      [ "TEXTINPUT", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0dae1c4a9cee7e1a452d3455b63f7bd2984", null ],
      [ "CONTROLLERAXISMOTION", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da02ad0ee43faa3821dafd230ddb885ccb", null ],
      [ "CONTROLLERBUTTONDOWN", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da0eb561d30eb04f7403af3fd1204870b0", null ],
      [ "CONTROLLERBUTTONUP", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da2d97ea0d3b7e53fd317627c2a8117f91", null ],
      [ "JOYAXISMOTION", "_ogre_input_8h.html#ggafba156da7d846753caa2c0be29f6da0da08dee7e7242f9584d5cfa108a8ade71d", null ]
    ] ]
];
